@@ -110,13 +110,13 @@ class XmlConfiguration:
 
 
 class ComplexArguments:
-    def __init__(self, sub_arg_objs: dict, with_group_prefix=False, conflict_warning=True):
-        self._parser = argparse.ArgumentParser()
+    def __init__(self, sub_arg_objs: dict, with_group_prefix=False, conflict_error=False):
+        self._parser = argparse.ArgumentParser(conflict_handler='error' if conflict_error else 'resolve')
         self._subparsers = self._parser.add_subparsers(help='sub-command help', dest='cmd')
         self._subparsers.required = True
         self._sub_arg_objs = sub_arg_objs
         self._with_group_prefix = with_group_prefix
-        self._conflict_warning = conflict_warning
+        self._conflict_error = conflict_error
         self._arg_objs = {}
         self.__create_args()
 
@@ -124,7 +124,7 @@ class ComplexArguments:
         for sub, arg_obj in self._sub_arg_objs.items():
             if arg_obj is None: continue
             parser = self._subparsers.add_parser(sub, help='{} help'.format(sub))
-            self._arg_objs[sub] = Arguments(arg_obj, parser, self._with_group_prefix, self._conflict_warning)
+            self._arg_objs[sub] = Arguments(arg_obj, parser, self._with_group_prefix, self._conflict_error)
 
     def _get_arg_obj(self, sub, args):
         argument: Arguments = self._arg_objs[sub]
@@ -141,11 +141,11 @@ class ComplexArguments:
 
 
 class Arguments:
-    def __init__(self, configObj, parser=None, with_group_prefix=False, conflict_warning=True):
-        self.parser = argparse.ArgumentParser() if parser is None else parser
+    def __init__(self, configObj, parser=None, with_group_prefix=False, conflict_error=False):
+        self.parser = argparse.ArgumentParser(
+            conflict_handler='error' if conflict_error else 'resolve') if parser is None else parser
         self.destObj = configObj
         self.with_group_prefix = with_group_prefix
-        self.conflict_warning = conflict_warning
         self.groups = dict()
         self.configInspector = ConfigInspector(self.destObj)
         self._arg_obj(self.configInspector, self.parser)
@@ -162,6 +162,7 @@ class Arguments:
     def __get_group(self, groupName, help=''):
         group = self.groups.get(groupName)
         if group is not None: return group
+        print(self.parser.conflict_handler)
         group = self.parser.add_argument_group(groupName, help)
         self.groups.setdefault(groupName, group)
         return group
@@ -175,10 +176,6 @@ class Arguments:
         if v is None: required = False
         name = name.replace('_', '-')
 
-        if parser.get_default(name) and self.conflict_warning:
-            print('WARNING: duplicated argument defined on: ' + name)
-            return self
-
         parser.add_argument('--' + name,
                             default=v,
                             required=required,
